#!/bin/bash

NO_JAVA_ERRMSG="Unable to locate 'java' in PATH environment variable.  Please add java to PATH."

function isJavaInPath {
	debug "path=`echo $PATH`"
	which java &> /dev/null
}

function debug {
	if [ ${DEBUG_SCRIPT:-false} = "true" ]; then
		echo DEBUG - $*
	fi
}

function exitWithError {
	echo $* 
	echo "Program exiting...."
	cd $ORG_DIR
	exit 1;
}

#
# Step 1.  Determine the directory containing Launcher.jar as 
#          Launcher.jar assumes it will be launched from there.
#          We 'cd' there before executing.
# 
DIRNAME=`dirname "$0"`
debug "dir=$DIRNAME"

ORG_DIR="$PWD"
cd $DIRNAME
debug "cd to $DIRNAME"


# 
# Step 2.  Add likely locations of 'java' to our path
# 
if [ ${JAVA_HOME:-unset} != "unset" ]; then
	debug "adding in JAVA_HOME to path"
	export PATH=$JAVA_HOME/bin:$PATH
fi
# If possible, use the java which came with our product
export PATH=../../jdk/jre/bin/:$PATH



#
# Step 3.  Complain if 'java' is not in our path
#
isJavaInPath
if [ $? -ne 0 ]; then
	debug "no java in path"
	exitWithError $NO_JAVA_ERRMSG
fi
debug "java in path java=`which java`"



#
# Step 4.  Execute making sure to cd to the starting directory before exiting.
#

java -jar Launcher.jar $*

RETURN_CODE=$?
debug "rc=$RETURN_CODE"

cd $ORG_DIR
exit $RETURN_CODE

